@@ -11,6 +11,8 @@
 #include <glib.h>
 #include <gudev/gudev.h>
 
+#include "accel-scale.h"
+
 typedef enum {
 	ACCEL_LOCATION_DISPLAY,
 	ACCEL_LOCATION_BASE,
@@ -20,5 +22,7 @@ AccelLocation setup_accel_location (GUdevDevice *device);
 
 gboolean parse_accel_location (const char    *location,
                                AccelLocation *value);
+gboolean parse_accel_label (const char    *location,
+                            AccelLocation *value);
 
-gdouble get_accel_scale (GUdevDevice *device);
\ No newline at end of file
+gboolean get_accel_scale (GUdevDevice *device, AccelScale *scale_vec);
